@@ -329,8 +329,8 @@ class ConfigManager:
         result = get_dict_item(self.local_config, ['template', 'render']) or {}
         # if os.path.isabs(render_path):
         #     raise DSOException(MESSAGES['AbsTemplateRenderPath'].format(render_path))
-        if os.path.isdir(render_path):
-            raise DSOException(MESSAGES['InvalidRenderPathExistingDir'].format(render_path))
+        # if os.path.isdir(render_path):
+        #     raise DSOException(MESSAGES['InvalidRenderPathExistingDir'].format(render_path))
         result[key] = render_path
         self.local_config['template']['render'] = result
         self.flush_local_config()
